@@ -3,14 +3,7 @@
 
 
 import warnings
-import cython
-import pyximport; pyximport.install()
-
-try:
-    from alacorder import cal
-except ImportError:
-    from alacorder import alac as cal
-
+from alacorder import alac as cal
 import os
 import sys
 import math
@@ -34,7 +27,7 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("77.5", package_name="alacorder")
+@click.version_option("77.5.5", package_name="alacorder")
 def cli():
     """
     ALACORDER beta 77.5
